@@ -8,6 +8,7 @@ from .const_7_api_auth import (
 from .const_7_api_info import DSM_7_API_INFO
 from .core.const_7_core_external_usb import (
     DSM_7_CORE_EXTERNAL_USB_DS1821_PLUS_EXTERNAL_USB,
+    DSM_7_CORE_EXTERNAL_USB_DS1821_PLUS_NO_EXTERNAL_USB,
 )
 from .core.const_7_core_upgrade import DSM_7_CORE_UPGRADE_FALSE, DSM_7_CORE_UPGRADE_TRUE
 from .dsm.const_7_dsm_info import DSM_7_DSM_INFORMATION
@@ -30,6 +31,7 @@ __all__ = [
     "DSM_7_AUTH_LOGIN_2SA_OTP",
     "DSM_7_API_INFO",
     "DSM_7_CORE_EXTERNAL_USB_DS1821_PLUS_EXTERNAL_USB",
+    "DSM_7_CORE_EXTERNAL_USB_DS1821_PLUS_NO_EXTERNAL_USB",
     "DSM_7_CORE_UPGRADE_FALSE",
     "DSM_7_CORE_UPGRADE_TRUE",
     "DSM_7_DSM_INFORMATION",
